svn commit: r256923 - head/usr.sbin/portsnap/portsnap

Gavin Atkinson gavin at FreeBSD.org
Tue Oct 22 18:55:53 UTC 2013


Author: gavin
Date: Tue Oct 22 18:55:52 2013
New Revision: 256923
URL: http://svnweb.freebsd.org/changeset/base/256923

Log:
  Rename the "alfred" command to "auto", and document it.  Retain support
  for "portsnap alfred" for now.
  
  Discussed:	many times, most recently on svn-src-all
  MFC after:	1 week

Modified:
  head/usr.sbin/portsnap/portsnap/portsnap.8
  head/usr.sbin/portsnap/portsnap/portsnap.sh

Modified: head/usr.sbin/portsnap/portsnap/portsnap.8
==============================================================================
--- head/usr.sbin/portsnap/portsnap/portsnap.8	Tue Oct 22 18:39:43 2013	(r256922)
+++ head/usr.sbin/portsnap/portsnap/portsnap.8	Tue Oct 22 18:55:52 2013	(r256923)
@@ -25,7 +25,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd October 14, 2012
+.Dd October 22, 2013
 .Dt PORTSNAP 8
 .Os FreeBSD
 .Sh NAME
@@ -161,6 +161,18 @@ or
 commands.
 Again, note that in the parts of the ports tree which are being
 updated, any local changes or additions will be removed.
+.It auto
+Run
+.Cm fetch
+or
+.Cm cron
+depending on whether stdin is a terminal; then run
+.Cm update
+or
+.Cm extract
+depending on whether
+.Ar portsdir
+exists.
 .El
 .Sh TIPS
 .Bl -bullet

Modified: head/usr.sbin/portsnap/portsnap/portsnap.sh
==============================================================================
--- head/usr.sbin/portsnap/portsnap/portsnap.sh	Tue Oct 22 18:39:43 2013	(r256922)
+++ head/usr.sbin/portsnap/portsnap/portsnap.sh	Tue Oct 22 18:55:52 2013	(r256923)
@@ -61,6 +61,8 @@ Commands:
                   files and directories.
   update       -- Update ports tree to match current snapshot, replacing
                   files and directories which have changed.
+  auto         -- Fetch updates, and either extract a new ports tree or
+                  update an existing tree.
 EOF
 	exit 0
 }
@@ -147,12 +149,15 @@ parse_cmdline() {
 			if [ ! -z "${SERVERNAME}" ]; then usage; fi
 			shift; SERVERNAME="$1"
 			;;
-		cron | extract | fetch | update | alfred)
+		cron | extract | fetch | update | auto)
 			COMMANDS="${COMMANDS} $1"
 			;;
 		up)
 			COMMANDS="${COMMANDS} update"
 			;;
+		alfred)
+			COMMANDS="${COMMANDS} auto"
+			;;
 		*)
 			if [ $# -gt 1 ]; then usage; fi
 			if echo ${COMMANDS} | grep -vq extract; then
@@ -1104,10 +1109,10 @@ cmd_update() {
 	update_run || exit 1
 }
 
 # Alfred command.  Run 'fetch' or 'cron' depending on
 # whether stdin is a terminal; then run 'update' or
 # 'extract' depending on whether ${PORTSDIR} exists.
-cmd_alfred() {
+cmd_auto() {
 	if [ "${INTERACTIVE}" = "YES" ]; then
 		cmd_fetch
 	else
@@ -1104,10 +1109,10 @@ cmd_update() {
 }
 
-# Alfred command.  Run 'fetch' or 'cron' depending on
+# Auto command.  Run 'fetch' or 'cron' depending on
 # whether stdin is a terminal; then run 'update' or
 # 'extract' depending on whether ${PORTSDIR} exists.


More information about the svn-src-head mailing list